{{{ topOfPage }}}
<!DOCTYPE html>
<!--[if lt IE 9]><html class="lte-ie8" lang="{{ htmlLang }}"><![endif]-->
<!--[if gt IE 8]><!--><html lang="{{ htmlLang }}"><!--<![endif]-->
  <head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8" />

    <title>{{ pageTitle }}</title>

    <script type="text/javascript">
      (function(){if(navigator.userAgent.match(/IEMobile\/10\.0/)){var d=document,c="appendChild",a=d.createElement("style");a[c](d.createTextNode("@-ms-viewport{width:auto!important}"));d.getElementsByTagName("head")[0][c](a);}})();
    </script>

    <!--[if gt IE 8]><!--><link href="{{{ assetPath }}}stylesheets/govuk-template.css?0.12.0" media="screen" rel="stylesheet" type="text/css" /><!--<![endif]-->
    <!--[if IE 6]><link href="{{{ assetPath }}}stylesheets/govuk-template-ie6.css?0.12.0" media="screen" rel="stylesheet" type="text/css" /><![endif]-->
    <!--[if IE 7]><link href="{{{ assetPath }}}stylesheets/govuk-template-ie7.css?0.12.0" media="screen" rel="stylesheet" type="text/css" /><![endif]-->
    <!--[if IE 8]><link href="{{{ assetPath }}}stylesheets/govuk-template-ie8.css?0.12.0" media="screen" rel="stylesheet" type="text/css" /><![endif]-->

    <link href="{{{ assetPath }}}stylesheets/govuk-template-print.css?0.12.0" media="print" rel="stylesheet" type="text/css" />

    <!--[if IE 8]>
    <script type="text/javascript">
      (function(){if(window.opera){return;}
       setTimeout(function(){var a=document,g,b={families:(g=
       ["nta"]),urls:["{{{ assetPath }}}stylesheets/fonts-ie8.css?0.12.0"]},
       c="{{{ assetPath }}}javascripts/vendor/goog/webfont-debug.js?0.12.0",d="script",
       e=a.createElement(d),f=a.getElementsByTagName(d)[0],h=g.length;WebFontConfig
       ={custom:b},e.src=c,f.parentNode.insertBefore(e,f);for(;h=h-1;a.documentElement
       .className+=' wf-'+g[h].replace(/\s/g,'').toLowerCase()+'-n4-loading');},0)
      })()
    </script>
    <![endif]-->
    <!--[if gte IE 9]><!-->
      <link href="{{{ assetPath }}}stylesheets/fonts.css?0.12.0" media="all" rel="stylesheet" type="text/css" />
    <!--<![endif]-->


    <!--[if lt IE 9]>
      <script src="{{{ assetPath }}}javascripts/ie.js?0.12.0" type="text/javascript"></script>
    <![endif]-->

    <link rel="shortcut icon" href="{{{ assetPath }}}images/favicon.ico?0.12.0" type="image/x-icon" />

    <!-- Size for iPad and iPad mini (high resolution) -->
    <link rel="apple-touch-icon-precomposed" sizes="152x152" href="{{{ assetPath }}}images/apple-touch-icon-152x152.png?0.12.0">
    <!-- Size for iPhone and iPod touch (high resolution) -->
    <link rel="apple-touch-icon-precomposed" sizes="120x120" href="{{{ assetPath }}}images/apple-touch-icon-120x120.png?0.12.0">
    <!-- Size for iPad 2 and iPad mini (standard resolution) -->
    <link rel="apple-touch-icon-precomposed" sizes="76x76" href="{{{ assetPath }}}images/apple-touch-icon-76x76.png?0.12.0">
    <!-- Default non-defined size, also used for Android 2.1+ devices -->
    <link rel="apple-touch-icon-precomposed" href="{{{ assetPath }}}images/apple-touch-icon-60x60.png?0.12.0">

    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta property="og:image" content="{{{ assetPath }}}images/opengraph-image.png?0.12.0">

    {{{ head }}}
  </head>

  <body class="{{ bodyClasses }}">
    <script type="text/javascript">document.body.className = ((document.body.className) ? document.body.className + ' js-enabled' : 'js-enabled');</script>

    {{{ bodyStart }}}

    <div id="skiplink-container">
      <div>
        <a href="#content" class="skiplink">Skip to main content</a>
      </div>
    </div>

    <div id="global-cookie-message">
      <div class="outer-block">
        <div class="inner-block">
          
            {{{ cookieMessage }}}
          
        </div>
      </div>
    </div>
    <!--end global-cookie-message-->

    
    <header role="banner" id="global-header" class="{{{ headerClass }}}">
      <div class="header-wrapper">
        <div class="header-global">
          <div class="header-logo">
            <a href="https://www.gov.uk/" title="Go to the GOV.UK homepage" id="logo" class="content">
              <img src="{{{ assetPath }}}images/gov.uk_logotype_crown.png?0.12.0" width="35" height="31" alt=""> GOV.UK
            </a>
          </div>
          {{{ insideHeader }}}
        </div>
        {{{ propositionHeader }}}
      </div>
    </header>
    <!--end header-->
    

    {{{ afterHeader }}}

    <div id="global-header-bar">
      <div class="inner-block">
        <div class="header-bar"></div>
      </div>
    </div>
    <!--end global-header-bar-->

    {{{ content }}}

    <footer class="group js-footer" id="footer" role="contentinfo">

      <div class="footer-wrapper">
        {{{ footerTop }}}

        <div class="footer-meta">
          <div class="footer-meta-inner">
            {{{ footerSupportLinks }}}

            <div class="open-government-licence">
              <p class="logo"><a href="https://www.nationalarchives.gov.uk/doc/open-government-licence/version/3/" rel="license">Open Government Licence</a></p>
              <p>All content is available under the <a href="https://www.nationalarchives.gov.uk/doc/open-government-licence/version/3/" rel="license">Open Government Licence v3.0</a>, except where otherwise stated</p>
            </div>
          </div>

          <div class="copyright">
            <a href="https://www.nationalarchives.gov.uk/information-management/our-services/crown-copyright.htm">&copy; Crown copyright</a>
          </div>
        </div>
      </div>
    </footer>

    <!--end footer-->

    <div id="global-app-error" class="app-error hidden"></div>

    <script src="{{{ assetPath }}}javascripts/govuk-template.js?0.12.0" type="text/javascript"></script>

    {{{ bodyEnd }}}
  </body>
</html>
