@font-face {
  font-family: GDS-Logo;
  src: local("HelveticaNeue"), local("Helvetica Neue"), local("Arial"), local("Helvetica"); }

@-ms-viewport {
  width: device-width; }

@-o-viewport {
  width: device-width; }

html {
  font-size: 62.5%; }

/* Global print stylesheet */
/* reset everything */
* {
  background: transparent;
  color: black;
  text-shadow: none;
  filter: none;
  -ms-filter: none; }

body {
  font-family: sans-serif;
  font-size: 11pt;
  line-height: 1.42857;
  font-weight: 400;
  text-transform: none;
  margin: 0;
  padding: 0;
  width: 100%; }
  @media (max-width: 640px) {
    body {
      font-size: 12px;
      line-height: 1.25; } }

a, a:visited {
  word-wrap: break-word; }

a[href^="/"]:after {
  content: " (https://www.gov.uk" attr(href) ")";
  font-size: 90%; }

a[href^="http://"]:after,
a[href^="https://"]:after {
  content: " (" attr(href) ")";
  font-size: 90%; }

a[href^="javascript:"]:after,
a[href^="#"]:after {
  content: ""; }

img {
  max-width: 100% !important; }

select {
  background: white; }

#global-header {
  color: #000;
  font-weight: bold;
  font-size: 24px;
  margin-bottom: 1em; }
  #global-header .content {
    margin: 0 !important; }
  #global-header a, #global-header a:visited {
    text-decoration: none; }
  #global-header a:after {
    content: ""; }
  #global-header img {
    display: none; }

/* hide the unnecessary page elements */
body footer,
.visuallyhidden,
#global-cookie-message,
#skiplink-container {
  display: none !important; }
