/* The below comment needs a ! so that the copyright message doesn't get removed during the minification step. See: http://sass-lang.com/docs/yardoc/file.SASS_REFERENCE.html#comments */

/*! Copyright (c) 2011 by Margaret Calvert & Henrik Kubel. All rights reserved. The font has been customised for exclusive use on gov.uk. This cut is not commercially available. */


@font-face {
  font-family: 'nta';
  src: url(fonts/NTA-Light-20130221.eot?0.12.0#) format('embedded-opentype');
  font-weight: normal;
  font-style: normal;
}

@font-face {
  font-family: 'nta';
  src: url(fonts/NTA-Bold-20130221.eot?0.12.0#) format('embedded-opentype');
  font-weight: bold;
}

@font-face {
  font-family: 'ntatabularnumbers';
  src: url(fonts/NTATabularNumbers-Light.eot?0.12.0#) format('embedded-opentype');
  font-weight: normal;
  font-style: normal;
}

@font-face {
  font-family: 'ntatabularnumbers';
  src: url(fonts/NTATabularNumbers-Bold.eot?0.12.0#) format('embedded-opentype');
  font-weight: bold;
}
